package com.engine.jucailin.cmd.calendar.holidaySet;

import com.engine.common.biz.AbstractCommonCommand;
import com.engine.common.biz.SimpleBizLogger;
import com.engine.common.constant.BizLogSmallType4Hrm;
import com.engine.common.constant.BizLogType;
import com.engine.common.entity.BizLogContext;
import com.engine.core.interceptor.CommandContext;
import weaver.conn.RecordSet;
import weaver.general.Util;
import weaver.hrm.HrmUserVarify;
import weaver.hrm.User;
import weaver.systeminfo.SystemEnv;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Author: sy
 * @Description: 节假日设置--编辑
 * @Date: 2024/2/28
 **/
public class EditHolidaySetWithCalendarSetCmd extends AbstractCommonCommand<Map<String, Object>> {

    private SimpleBizLogger logger;

    public EditHolidaySetWithCalendarSetCmd(Map<String, Object> params, User user) {
        this.user = user;
        this.params = params;
        this.logger = new SimpleBizLogger();

        String calendarId = Util.null2String(params.get("calendarId"));//日历设置的ID，取自kq_calendar_name中id
        String syncCalendarIds = Util.null2String(params.get("syncCalendarIds"));//需要同步的日历设置ID
        String calendarIds = calendarId + (syncCalendarIds.equals("") ? "" : ("," + syncCalendarIds));
        BizLogContext bizLogContext = new BizLogContext();
        bizLogContext.setLogType(BizLogType.HRM_ENGINE);//模块类型
        bizLogContext.setBelongType(BizLogSmallType4Hrm.HRM_ENGINE_KQ_HOLIDAYSET);//所属大类型
        bizLogContext.setLogSmallType(BizLogSmallType4Hrm.HRM_ENGINE_KQ_HOLIDAYSET);//当前小类型
        bizLogContext.setParams(params);//当前request请求参数
        logger.setUser(user);//当前操作人
        String mainSql = "select * from kq_HolidaySet where calendarId in (" + calendarIds + ")";
        logger.setMainSql(mainSql, "id");//主表sql
        logger.setMainPrimarykey("id");//主日志表唯一key
        logger.setMainTargetNameMethod("com.engine.kq.util.KQTransMethod.getTargetName4HolidaySet","column:calendarId+column:holidayDate+"+user.getLanguage());//当前targetName对应的列（对应日志中的对象名）
        logger.before(bizLogContext);
    }

    @Override
    public BizLogContext getLogContext() {
        return null;
    }

    @Override
    public List<BizLogContext> getLogContexts() {
        return logger.getBizLogContexts();
    }

    @Override
    public Map<String, Object> execute(CommandContext commandContext) {
        Map<String, Object> resultMap = new HashMap<String, Object>();
        String id = Util.null2String(params.get("id"));//ID
        String calendarId = Util.null2String(params.get("calendarId"));//日历设置的ID，取自kq_calendar_name中id
        String holidayDate = Util.null2String(params.get("holidayDate"));//日期
        String changeType = Util.null2String(params.get("changeType"));//类型：1-公众假日、2-调配工作日、3-调配休息日
        String holidayDesc = Util.null2String(params.get("holidayDesc"));//说明
        int relatedDay = Util.getIntValue((String) params.get("relatedDay"), -1);//对应工作日：0-星期一、1-星期二、2-星期三、3-星期四、4-星期五、5-星期六、6-星期日
        String isSync = Util.null2String(params.get("isSync"));//是否需要同步到其他考勤组
        String syncCalendarIds = Util.null2String(params.get("syncCalendarIds"));//需要同步的日历设置ID

        try {
            boolean canEdit = HrmUserVarify.checkUserRight("KQHolidaySetEdit:Edit", user);
            if (!canEdit) {
                resultMap.put("status", "-1");
                resultMap.put("message", SystemEnv.getHtmlLabelName(2012, user.getLanguage()));
                return resultMap;
            }


            String updateSql = "update kq_HolidaySet set changeType=?,holidayDesc=?,relatedDay=?,calendarId=?,holidayDate=? where id=?";
            RecordSet recordSet = new RecordSet();
            boolean flag = recordSet.executeUpdate(updateSql, changeType, holidayDesc, relatedDay, calendarId, holidayDate, id);
            if (flag) {
                resultMap.put("sign", "1");
                resultMap.put("message", SystemEnv.getHtmlLabelName(83551, user.getLanguage()));//保存成功
            } else {
                resultMap.put("sign", "-1");
                resultMap.put("message", SystemEnv.getHtmlLabelName(84544, user.getLanguage()));//保存失败
                return resultMap;
            }

            /**
             * 同步到其他日历设置
             * 如果这一天已经设置过数据，删除掉后再重新插入
             */
            String deleteSql = "delete from kq_HolidaySet where calendarId=? and holidayDate=?";
            String insertSql = " insert into kq_HolidaySet(calendarId,holidayDate,changeType,holidayDesc,relatedDay) values(?,?,?,?,?)";
//            KQGroupComInfo kqGroupComInfo = new KQGroupComInfo();
            if (isSync.equals("1") || isSync.equals("true")) {
                List<String> syncCalendarIdList = Util.TokenizerString(syncCalendarIds, ",");
                for (int j = 0; j < syncCalendarIdList.size(); j++) {
                    String tempCalendarId = syncCalendarIdList.get(j);
//                    if (Util.null2String(kqGroupComInfo.getKqtype(tempGroupId)).equals("2") && changeType.equals("2")) {
//                        continue;
//                    }
                    recordSet.executeUpdate(deleteSql, tempCalendarId, holidayDate);

                    flag = recordSet.executeUpdate(insertSql, tempCalendarId, holidayDate, changeType, holidayDesc, relatedDay);
                    if (!flag) {
                        resultMap.put("sign", "-1");
                        resultMap.put("message", SystemEnv.getHtmlLabelName(84544, user.getLanguage()));//保存失败
                        return resultMap;
                    }
                }
            }

            if (flag) {
                resultMap.put("sign", "1");
                resultMap.put("message", SystemEnv.getHtmlLabelName(83551, user.getLanguage()));//保存成功
            } else {
                resultMap.put("sign", "-1");
                resultMap.put("message", SystemEnv.getHtmlLabelName(84544, user.getLanguage()));//保存失败
            }
        } catch (Exception e) {
            resultMap.put("sign", "-1");
            resultMap.put("message", SystemEnv.getHtmlLabelName(382661, user.getLanguage()));
            writeLog(e);
        }finally {
//            /*刷新缓存*/
//            Kring> holidayDateList = new ArrayList<String>();
//            holidayQHolidaySetComInfo holidaySetComInfo = new KQHolidaySetComInfo();
////            holidaySetComInfo.removeCache();
////
////            /*刷新报表*/
////            List<String> groupIdList = new ArrayList<String>();
////            if (isSync.equals("1") || isSync.equals("true")) {
////                groupIdList = Util.TokenizerString(syncGroupIds, ",");
////                if(groupIdList==null){
////                    groupIdList = new ArrayList<String>();
////                }
////            }
////            groupIdList.add(groupId);
////            List<StDateList.add(holidayDate);
//            new KQHolidaySetThread(groupIdList,holidayDateList).start();
        }
        return resultMap;
    }
}
